/// @file   Application.hpp
/// @author Armin Co
///

#ifndef GUI_CORE_APPLICATION_HPP
#define GUI_CORE_APPLICATION_HPP

#include <string>
#include <memory>

#include "Event.hpp"
#include "IWindow.hpp"
#include "LayerStack.hpp"
#include "ImGuiLayer.hpp"
#include "ApplicationEvent.hpp"

namespace GuiCore
{
    class Application
    {
    public:
        Application(const std::string &name = "Application", uint32_t width = 1280, uint32_t height = 720);
        virtual ~Application() {}

        void run();
        void onEvent(Event &e);
        void pushLayer(std::shared_ptr<Layer> layer);
        void popLayer(std::shared_ptr<Layer> layer);
        IWindow& getWindow();
        bool onWindowClose(Event &e);
        bool onWindowResize(Event &e);

        static Application& get();

    private:
        std::unique_ptr<IWindow> m_window;
        bool m_isRunnig = true;
        bool m_minimzed = false;
        LayerStack m_layerStack;
        float m_lastFrameTime = 0.0f;
        std::shared_ptr<ImGuiLayer> m_guiLayer;

        static Application *s_instance;
    };
}

#endif