/// @file   IWindow.hpp
/// @author Armin Co
///

#ifndef GUI_CORE_WINDOW_HPP
#define GUI_CORE_WINDOW_HPP

#include <string>
#include <functional>

#include "Event.hpp"

namespace GuiCore
{
    struct WindowProperties
    {
        std::string title;
        uint32_t width;
        uint32_t height;

        WindowProperties(const std::string &t = "Application", uint32_t w = 1280, uint32_t h = 720)
            : title{t}
            , width{w}
            , height{h}
            {
            }
    };

    class IWindow
    {
    public:
        virtual ~IWindow() {}
        virtual void onUpdate() = 0;
        virtual uint32_t getWidth() const = 0;
        virtual uint32_t getHeight() const = 0;

        virtual void setEventCallback(const std::function<void(GuiCore::Event&)>) = 0;
        virtual void setVSync(bool enabled) = 0;
        virtual bool isVSyncEnabled() const = 0;
        virtual void* getNativeWindow() const = 0;

        static IWindow* create(const WindowProperties &props = WindowProperties());
    };
}

#endif