/// @file   Input.cpp
/// @author Armin Co
///

#include "Input.hpp"
#include "Application.hpp"

#include <GLFW/glfw3.h>

namespace GuiCore
{
    Input* Input::s_instance = new Input();

    bool Input::isKeyPressed(int keyCode)
    {
        auto window = static_cast<GLFWwindow*>(Application::get().getWindow().getNativeWindow());
        auto state = glfwGetKey(window, keyCode);
        return state == GLFW_PRESS || state == GLFW_REPEAT;
    }

    bool Input::isMouseButtonPressed(int button)
    {
        auto window = static_cast<GLFWwindow*>(Application::get().getWindow().getNativeWindow());
        auto state = glfwGetMouseButton(window, button);
        return state == GLFW_PRESS;
    }

    std::pair<float, float> Input::getMousePosition()
    {
        auto window = static_cast<GLFWwindow*>(Application::get().getWindow().getNativeWindow());
        double xPos {0};
        double yPos {0};
        glfwGetCursorPos(window, &xPos, &yPos);
        return {static_cast<float>(xPos), static_cast<float>(yPos)};
    }

    float Input::getMouseX()
    {
        auto[x, y] = getMousePosition();
        return x;
    }

    float Input::getMouseY()
    {
        auto[x, y] = getMousePosition();
        return y;
    }
}