/// @file   LayerStack.cpp
/// @author Armin Co
///

#include <algorithm>

#include "LayerStack.hpp"

namespace GuiCore
{
    LayerStack::LayerStack()
    {
    }

    LayerStack::~LayerStack()
    {
        for (auto layer : m_layers)
        {
            layer->~Layer();
        }
    }

    void LayerStack::pushLayer(std::shared_ptr<Layer> layer)
    {
        m_layers.emplace(lastLayer(), layer);
        ++m_layerIndex;
        layer->onAttach();
    }

    void LayerStack::popLayer(std::shared_ptr<Layer> layer)
    {
        auto it = std::find(firstLayer(), lastLayer(), layer);
        if (it != lastLayer())
        {
            layer->onDetach();
            m_layers.erase(it);
            --m_layerIndex;
        }
    }

    Layers::iterator LayerStack::begin()
    {
        return m_layers.begin();
    }

    Layers::iterator LayerStack::end()
    {
        return m_layers.end();
    }

    Layers::iterator LayerStack::firstLayer()
    {
        return m_layers.begin();
    }

    Layers::iterator LayerStack::lastLayer()
    {
        return m_layers.begin() + m_layerIndex;
    }

    Layers::reverse_iterator LayerStack::rbegin()
    {
        return m_layers.rbegin();
    }

    Layers::reverse_iterator LayerStack::rend()
    {
        return m_layers.rend();
    }
}
