/// @file   LayerStack.hpp
/// @author Armin Co
///

#ifndef GUI_CORE_LAYERSTACK_HPP
#define GUI_CORE_LAYERSTACK_HPP

#include <vector>
#include <memory>

#include "Layer.hpp"

namespace GuiCore
{
    using Layers = std::vector<std::shared_ptr<Layer>>;

    class LayerStack
    {
    public:
        LayerStack();
        ~LayerStack();

        void pushLayer(std::shared_ptr<Layer> layer);
        void popLayer(std::shared_ptr<Layer> layer);

        Layers::iterator begin();
        Layers::iterator end();
        Layers::reverse_iterator rbegin();
        Layers::reverse_iterator rend();

    private:
        Layers::iterator firstLayer();
        Layers::iterator lastLayer();

        Layers m_layers;
        uint32_t m_layerIndex{0};
    };
}

#endif