/// @file   MainMenuLayer.cpp
/// @author Armin Co
///

#include "MainMenuLayer.hpp"

#include <imgui/imgui.h>
#include <GuiCore/Application.hpp>

#include "GameLayer.hpp"
#include <glm/gtc/type_ptr.hpp>

using namespace QPong;

MainMenuLayer::MainMenuLayer()
    : m_selectedResolution {512}
    , m_resetOnce {false} 
    , m_gameAttached {false}
{
}

void MainMenuLayer::onAttach()
{
    glEnable(GL_DEPTH_TEST);
    glDepthFunc(GL_LESS);
    glEnable(GL_BLEND);
    glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
    m_backgroundColor = {0.2f, 0.2f, 0.2f};
    createNewGame();
}

void MainMenuLayer::onDetach()
{

}

void MainMenuLayer::createNewGame()
{
     m_resetOnce = false;
    if (m_gameAttached)
    {
        GuiCore::Application::get().popLayer(m_gameLayer);
        m_gameAttached = false;
    }
    m_gameLayer = std::make_shared<GameLayer>(m_selectedResolution);
    GuiCore::Application::get().pushLayer(m_gameLayer);
    m_gameAttached = true;
}

void MainMenuLayer::onUpdate(GuiCore::Timestep ts)
{
    m_fps = 1000.0 / ts.getMilliseconds();
    glClearColor(m_backgroundColor.r, m_backgroundColor.g, m_backgroundColor.b, 1.0f);
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);

    if (m_resetOnce)
    {
       createNewGame();
    }

}

void MainMenuLayer::onGuiRender()
{
    ImGui::Begin("Main Menu");
    ImGui::Text("FPS: %3.1f", m_fps);
    ImGui::DragInt("Resolution", &m_selectedResolution, 16, 16, 1088);
    ImGui::ColorEdit3("Background Color", glm::value_ptr(m_backgroundColor));
    if (ImGui::Button("Reset")){ m_resetOnce = true; }
    if (ImGui::IsItemHovered()) {
        ImGui::SetTooltip("Reinitialise Simulation with selected array resolution.");
    }
    ImGui::End();
}

void MainMenuLayer::onEvent(GuiCore::Event &event)
{

}
