/// @file   MainMenuLayer.hpp
/// @author Armin Co
///

#ifndef QPONG_MAIN_MENU_LAYER_HPP
#define QPONG_MAIN_MENU_LAYER_HPP

#include <GuiCore/Layer.hpp>
#include <GuiCore/Timestep.hpp>

#include <glm/glm.hpp>

namespace QPong
{
/// @brief The main menu holds the controls to restart the game
///         with different simulation settings.
///
class MainMenuLayer : public GuiCore::Layer
{
public:
    MainMenuLayer();
    virtual ~MainMenuLayer(){};
    virtual void onAttach() override;
    virtual void onDetach() override;
    virtual void onUpdate(GuiCore::Timestep ts) override;
    virtual void onGuiRender() override;
    virtual void onEvent(GuiCore::Event &event) override;

private:
    void createNewGame();

    int m_selectedResolution; ///< selected res in the gui
    bool m_resetOnce; ///< restart simulation if set
    std::shared_ptr<GuiCore::Layer> m_gameLayer; ///< holds ref to the game
    bool m_gameAttached;
    float m_fps;
    glm::vec3 m_backgroundColor;
};
}
#endif