/// @file   Window.hpp
/// @author Armin Co
///

#ifndef QPONG_APP_WINDOW_HPP
#define QPONG_APP_WINDOW_HPP


#include <GLFW/glfw3.h>
#include <GuiCore/IWindow.hpp>

#include <GuiCore/Event.hpp>

class Window : public GuiCore::IWindow
{
public:
    Window(const GuiCore::WindowProperties &properties);
    virtual ~Window();

    void onUpdate() override;

    uint32_t getWidth() const override;
    uint32_t getHeight() const override;

    virtual void setEventCallback(const std::function<void(GuiCore::Event&)>) override;
    void setVSync(bool enabled) override;
    bool isVSyncEnabled() const override;

    void* getNativeWindow() const override;

private:
    virtual void setup(const GuiCore::WindowProperties &properties);
    virtual void shutdown();

    GLFWwindow* m_window;

    struct Data
    {
        std::string title;
        uint32_t width;
        uint32_t height;
        bool vSyncEnabled;

        std::function<void(GuiCore::Event&)> eventCallback;
    };
    Data m_data;
};
#endif